Module: Google::Cloud::NetworkSecurity
- Defined in:
- lib/google/cloud/network_security.rb,
lib/google/cloud/network_security/version.rb
Constant Summary collapse
- VERSION =
"0.1.1"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.network_security| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-network_security library.
-
.network_security(version: :v1beta1, &block) ⇒ NetworkSecurity::Client
Create a new client object for NetworkSecurity.
Class Method Details
.configure {|::Google::Cloud.configure.network_security| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-network_security library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional gRPC headers to be sent with the call.-
retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys:* `:initial_delay` (*type:* `Numeric`) - The initial delay in seconds. * `:max_delay` (*type:* `Numeric`) - The max delay in seconds. * `:multiplier` (*type:* `Numeric`) - The incremental backoff multiplier. * `:retry_codes` (*type:* `Array<String>`) - The error codes that should trigger a retry.
107 108 109 110 111 |
# File 'lib/google/cloud/network_security.rb', line 107 def self.configure yield ::Google::Cloud.configure.network_security if block_given? ::Google::Cloud.configure.network_security end |
.network_security(version: :v1beta1, &block) ⇒ NetworkSecurity::Client
Create a new client object for NetworkSecurity.
By default, this returns an instance of
Google::Cloud::NetworkSecurity::V1beta1::NetworkSecurity::Client
for version V1beta1 of the API.
However, you can specify specify a different API version by passing it in the
version parameter. If the NetworkSecurity service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About NetworkSecurity
Network Security API provides resources to configure authentication and authorization policies. Refer to per API resource documentation for more information.
68 69 70 71 72 73 74 75 76 77 |
# File 'lib/google/cloud/network_security.rb', line 68 def self.network_security version: :v1beta1, &block require "google/cloud/network_security/#{version.to_s.downcase}" package_name = Google::Cloud::NetworkSecurity .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first package_module = Google::Cloud::NetworkSecurity.const_get package_name package_module.const_get(:NetworkSecurity).const_get(:Client).new(&block) end |